@@ -5,7 +5,7 @@ import (
 )
 
 type Java struct {
-	language
+	Language
 }
 
 func (j *Java) Template() string {
@@ -15,7 +15,7 @@ func (j *Java) Template() string {
 func (j *Java) Enabled() bool {
 	j.init()
 
-	return j.language.Enabled()
+	return j.Language.Enabled()
 }
 
 func (j *Java) init() {
