@@ -4,6 +4,7 @@ import (
 	"encoding/json"
 	"path"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 )
 
@@ -15,7 +16,7 @@ const (
 )
 
 type Sitecore struct {
-	base
+	Base
 
 	EndpointName string
 	CmHost       string
@@ -32,14 +33,14 @@ type UserConfig struct {
 
 func (s *Sitecore) Enabled() bool {
 	if !s.env.HasFiles(sitecoreFileName) || !s.env.HasFilesInDir(sitecoreFolderName, userFileName) {
-		s.env.Debug("sitecore cli configuration files were not found")
+		log.Debug("sitecore cli configuration files were not found")
 		return false
 	}
 
 	var userConfig, err = getUserConfig(s)
 
 	if err != nil {
-		s.env.Error(err)
+		log.Error(err)
 		return false
 	}
 
@@ -48,7 +49,7 @@ func (s *Sitecore) Enabled() bool {
 	displayDefault := s.props.GetBool(properties.DisplayDefault, true)
 
 	if !displayDefault && s.EndpointName == defaultEnpointName {
-		s.env.Debug("displaying of the default environment is turned off")
+		log.Debug("displaying of the default environment is turned off")
 		return false
 	}
 
